@@ -284,8 +284,20 @@ void dviRenderer::prescan_ParsePSHeaderSpecial(const QString& cp)
   kdDebug(4300) << "PostScript-special, header " << cp.latin1() << endl;
 #endif
 
-  if (QFile::exists(cp)) 
-    PS_interface->PostScriptHeaderString->append( QString(" (%1) run\n").arg(cp) );
+  QString _file = cp;
+  
+  // If the file is not found in the current directory, use kpsewhich
+  // to find it.
+  if (!QFile::exists(_file)) {
+    // Otherwise, use kpsewhich to find the eps file.
+    KProcIO proc;
+    proc << "kpsewhich" << cp;
+    proc.start(KProcess::Block);
+    proc.readln(_file);
+  }
+  
+  if (QFile::exists(_file))
+    PS_interface->PostScriptHeaderString->append( QString(" (%1) run\n").arg(_file) );
 }
 
 
@@ -305,7 +317,6 @@ void dviRenderer::prescan_ParsePSQuoteSpecial(const QString& cp)
 {
 #ifdef DEBUG_PRESCAN
   kdError(4300) << "PostScript-special, literal PostScript " << cp.latin1() << endl;
-
 #endif
   
   double PS_H = (currinf.data.dvi_h*300.0)/(65536*1200)-300;
