@@ -11,8 +11,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -32,11 +32,6 @@ public:
     KGifPlugin( QObject *parent, const char *name, const QStringList& args );
 
     virtual bool readInfo ( KFileMetaInfo& info, uint what );
-    virtual bool writeInfo( const KFileMetaInfo& info ) const;
-    virtual QValidator* createValidator( const QString& mimetype,
-                                         const QString& group,
-                                         const QString& key,
-                                         QObject* parent, const char* name) const;
 };
 
 #endif
