@@ -12,10 +12,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- *  $Id: kfile_ps.h 293705 2004-03-05 01:29:20Z luis_pedro $
+ *  $Id: kfile_ps.h 465369 2005-09-29 14:33:08Z mueller $
  */
 
 #ifndef __KFILE_PS_H__
@@ -37,6 +37,7 @@ public:
     virtual bool readInfo( KFileMetaInfo& info, uint what);
 
     void comment( Name );
+    void makeMimeTypeInfo(  const char* mimeType );
     
 private:
     KFileMetaInfo _info;
