@@ -17,7 +17,7 @@
   copies.
 */
 
-/* $Id: dscparse.cpp 636821 2007-02-24 10:47:12Z mueller $ */
+/* $Id: dscparse.cpp 666774 2007-05-20 21:18:12Z savernik $ */
 
 /* dscparse.c - DSC parser  */
 
@@ -83,7 +83,7 @@
 #define CDSC_NEEDMORE 11
 
 template<class T>
-inline const T min (const T& a, const T& b) { return a < b ? a : b; }
+inline T min (T a, T b) { return a < b ? a : b; }
 
 /* local prototypes */
 dsc_private void * dsc_memalloc(P2(CDSC *dsc, size_t size));
