@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef DSCPARSE_ADAPTER_H
@@ -27,8 +27,6 @@
 #include <qstring.h>
 
 #include "dscparse.h"
-#undef min
-#undef max
 
 #if defined(__GNUC__)
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 93)
@@ -154,6 +152,7 @@ private:
 class KDSCErrorHandler
 {
 public:
+    virtual ~KDSCErrorHandler() {}
     enum Response 
     { 
 	Ok        = CDSC_RESPONSE_OK, 
@@ -172,6 +171,7 @@ class KDSCOkErrorHandler : public KDSCErrorHandler
 class KDSCCommentHandler
 {
 public:
+    virtual ~KDSCCommentHandler() {}
     enum Name
     {
 	// Header section
@@ -355,6 +355,7 @@ private:
 class KDSCScanHandler
 {
 public:
+    virtual ~KDSCScanHandler() {}
     KDSCScanHandler( CDSC* cdsc ) : _cdsc( cdsc ) {}
     
     virtual bool scanData( char* buf, unsigned int count )
