@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qfile.h>
@@ -258,17 +258,19 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _zoomTo->setEditable(  true );
     _zoomTo->clear();
     QValueList<double> mags = DisplayOptions::normalMagnificationValues();
-    QStringList translated;
+    QStringList zooms;
     int idx = 0;
     int cur = 0;
     for ( QValueList<double>::iterator first = mags.begin(), last = mags.end();
 	    first != last;
 	    ++first ) {
-	translated << i18n( "zoom-factor (percentage)", "%1%" ).arg( *first * 100.0 );
+        QString str = QString( "%1%" ).arg( KGlobal::locale()->formatNumber( *first * 100.0, 2 ));
+        str.remove( KGlobal::locale()->decimalSymbol() + "00" );
+        zooms << str;
 	if ( *first == 1.0 ) idx = cur;
 	++cur;
     }
-    _zoomTo->setItems( translated );
+    _zoomTo->setItems( zooms );
     _zoomTo->setCurrentItem( idx );
 
     _fitWidth = new KAction( i18n( "&Fit to Page Width" ), 0, this,
@@ -296,13 +298,13 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
 
     KShortcut readUpShort = KStdAccel::shortcut( KStdAccel::Prior );
     readUpShort.append( KKey( SHIFT+Key_Space ) );
-    _readUp    = new KAction( i18n( "Read Up Document" ), "up",
+    _readUp    = new KAction( i18n( "Read Up" ), "up",
                               readUpShort, this, SLOT( slotReadUp() ),
                               actionCollection(), "readUp" );
 
     KShortcut readDownShort = KStdAccel::shortcut( KStdAccel::Next );
     readDownShort.append( KKey( Key_Space ) );
-    _readDown  = new KAction( i18n( "Read Down Document" ), "down",
+    _readDown  = new KAction( i18n( "Read Down" ), "down",
                               readDownShort, this, SLOT( slotReadDown() ),
                               actionCollection(), "readDown" );
 
@@ -598,7 +600,9 @@ void KGVPart::updateZoomActions()
     }
 
     // Show percentage that isn't predefined
-    items.insert( items.at(idx), 1, i18n( "zoom-factor (percentage)", "%1%" ).arg( zoom ) );
+    QString str = QString( "%1%" ).arg( KGlobal::locale()->formatNumber( zoom, 2 ));
+    str.remove( KGlobal::locale()->decimalSymbol() + "00" );
+    items.insert( items.at(idx), 1, str );
     _zoomTo->setItems( items );
     _zoomTo->setCurrentItem( idx );
     _customZoomIndex = idx;
