@@ -2,8 +2,8 @@
 #define VIEWCONTROL_H
 
 #include <qdialog.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
+class QComboBox;
+class QPushButton;
 
 
 class ViewControl : public QDialog
@@ -23,7 +23,7 @@ public:
 
 	/**
 	 * Enable/disable the apply button.
-	 **/ 
+	 **/
 	void applyEnable (bool enable);
 
 protected:
@@ -40,3 +40,5 @@ signals:
 };
 
 #endif
+
+// vim:sw=4:sts=4:ts=8:noet
