@@ -16,6 +16,7 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include <qlabel.h>
 #include <qlayout.h>
 
 #include <kaboutdata.h>
@@ -26,6 +27,8 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kgenericfactory.h>
+#include <kstandarddirs.h>
+#include <kurllabel.h>
 
 #include "kcmkmrml.h"
 #include <dcopclient.h>
@@ -63,13 +66,40 @@ KCMKMrml::KCMKMrml(QWidget *parent, const char *name, const QStringList & ):
 
     connect( m_mainPage, SIGNAL( changed( bool ) ), SIGNAL( changed( bool )));
 
-    load();
+    checkGiftInstallation();
 }
 
 KCMKMrml::~KCMKMrml()
 {
 }
 
+void KCMKMrml::checkGiftInstallation()
+{
+    QString giftExe = KGlobal::dirs()->findExe( "gift" );
+    QString giftAddCollectionExe = KGlobal::dirs()->findExe( "gift-add-collection.pl" );
+
+    if ( giftExe.isEmpty() || giftAddCollectionExe.isEmpty() )
+    {
+        QString errorMessage = 
+            i18n("Cannot find executables \"gift\" and/or \"gift-add-collection.pl\" in the PATH.\n"
+                 "Please install the \"GNU Image Finding Tool\".");
+        KMessageBox::error( this, errorMessage );
+        m_mainPage->hide();
+        QLabel *errorLabel = new QLabel( errorMessage, this );
+        errorLabel->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+        KURLLabel *urlLabel = new KURLLabel( "http://www.gnu.org/software/gift", QString::null, this ); 
+        urlLabel->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
+        connect( urlLabel, SIGNAL( leftClickedURL( const QString& )), kapp, SLOT( invokeBrowser( const QString& )) );
+        QLayout *l = layout();
+        l->addItem( new QSpacerItem( 0, 10, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
+        l->add( errorLabel );
+        l->add( urlLabel );
+        l->addItem( new QSpacerItem( 0, 10, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
+        errorLabel->show();
+    }
+    else
+        load();
+}
 
 void KCMKMrml::defaults()
 {
