@@ -291,7 +291,7 @@ ServerSettings::ServerSettings( const QString& host, unsigned short int port,
 ServerSettings ServerSettings::defaults()
 {
     return ServerSettings( DEFAULT_HOST, DEFAULT_PORT,
-                           (QString(DEFAULT_HOST) == "localhost" && DEFAULT_PORT),
+                           (!strcmp(DEFAULT_HOST, "localhost") && DEFAULT_PORT),
                            DEFAULT_AUTH, DEFAULT_USER, DEFAULT_PASS );
 }
 
