@@ -152,7 +152,7 @@ bool PDFGenerator::loadDocument( const QString & filePath, QValueVector<KPDFPage
         }
 
         // 2. reopen the document using the password
-        GString * pwd2 = new GString( password.data() );
+        GString * pwd2 = new GString( QString::fromLocal8Bit(password.data()).latin1() );
             delete pdfdoc;
         pdfdoc = new PDFDoc( new GString( QFile::encodeName( filePath ) ), pwd2, pwd2 );
             delete pwd2;
@@ -455,11 +455,18 @@ bool PDFGenerator::print( KPrinter& printer )
     {
         pstitle = m_document->currentDocument().fileName( false );
     }
-    QCString pstitle8Bit = pstitle.local8Bit();
+    // this looks non-unicode-safe and it is. anything other than ASCII is not specified
+    // and some printers actually stop printing when they encounter non-ASCII characters in the
+    // Postscript %%Title tag
+    QCString pstitle8Bit = pstitle.latin1();
     const char* pstitlechar;
     if (!pstitle.isEmpty())
     {
       pstitlechar = pstitle8Bit.data();
+      for (unsigned char* p = (unsigned char*) pstitle8Bit.data(); *p; ++p)
+          if (*p >= 0x80)
+              *p = '?';
+
       printer.setDocName(pstitle);
     }
     else
@@ -808,7 +815,7 @@ QString PDFGenerator::getDocumentDate( const QString & data ) const
         if ( s[0] == 'D' && s[1] == ':' )
             s = s.mid(2);
 
-        if ( sscanf( s.latin1(), "%4d%2d%2d%2d%2d%2d", &year, &mon, &day, &hour, &min, &sec ) == 6 )
+        if ( !s.isEmpty() && sscanf( s.latin1(), "%4d%2d%2d%2d%2d%2d", &year, &mon, &day, &hour, &min, &sec ) == 6 )
         {
             QDate d( year, mon, day );  //CHECK: it was mon-1, Jan->0 (??)
             QTime t( hour, min, sec );
