@@ -23,7 +23,7 @@
 
 #include <klocale.h>
 
-PMDefinePropertyClass( PMBoundedBy, PMProperty );
+PMDefinePropertyClass( PMBoundedBy, PMBoundedByProperty );
 
 PMMetaObject* PMBoundedBy::s_pMetaObject = 0;
 PMObject* createNewBoundedBy( PMPart* part )
@@ -47,7 +47,7 @@ PMMetaObject* PMBoundedBy::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "BoundedBy", Base::metaObject( ),
                                         createNewBoundedBy );
       s_pMetaObject->addProperty(
-         new PMProperty( "clippedBy", 0, &PMBoundedBy::clippedBy ) );
+         new PMBoundedByProperty( "clippedBy", 0, &PMBoundedBy::clippedBy ) );
    }
    return s_pMetaObject;
 }
