@@ -32,6 +32,8 @@ PMHeightFieldROAM::PMHeightFieldROAM( const QString &fileName )
    m_waterLevel = m_displayDetail = 0;
    m_mapMod = m_levelMod = true;
    m_fail = false;
+   m_pPoints = 0;
+   m_pTree = 0;
 
    if ( !imageToData( fileName ) )
    {
