@@ -346,7 +346,7 @@ void PMMesh::controlPointsChangedList( PMControlPointList& list, PMObjectList& o
    int listID, pointID, numCP;
 
    // have to cache changed values because checking once changes them to false
-   bool changed[ list.count( ) ];
+   QMemArray<bool> changed( list.count( ) );
    p = list.first( );
    for ( int i = 0; p; ++i, p = list.next( ) )
       changed[i] = p->changed( );
