@@ -35,7 +35,7 @@ const int c_defaultOrder = 2;
 const bool c_defaultSturm = true;
 const int c_polynomSize[8] = { 0, 0, 10, 20, 35, 56, 84, 120 };
 
-PMDefinePropertyClass( PMPolynom, PMProperty );
+PMDefinePropertyClass( PMPolynom, PMPolynomProperty );
 
 class PMCoefficientProperty : public PMPropertyBase
 {
@@ -137,10 +137,10 @@ PMMetaObject* PMPolynom::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "Polynom", Base::metaObject( ),
                                         createNewPolynom );
       s_pMetaObject->addProperty(
-         new PMProperty( "polynomOrder", &PMPolynom::setPolynomOrder,
+         new PMPolynomProperty( "polynomOrder", &PMPolynom::setPolynomOrder,
                          &PMPolynom::polynomOrder ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "sturm", &PMPolynom::setSturm,
+         new PMPolynomProperty( "sturm", &PMPolynom::setSturm,
                          &PMPolynom::sturm ) );
 
       s_pMetaObject->addProperty( new PMCoefficientProperty( ) );
