@@ -20,9 +20,6 @@
 #include "pmskysphere.h"
 #include "pmlinkedit.h"
 
-#include <kdebug.h>
-#include "pmglobals.h"
-
 #include <qlayout.h>
 #include <qlabel.h>
 #include <klocale.h>
@@ -36,7 +33,7 @@ PMSkySphereEdit::PMSkySphereEdit( QWidget* parent, const char* name )
 
 void PMSkySphereEdit::displayObject( PMObject* o )
 {
-   if( o->isA( PMTSkySphere ) )
+   if( o->isA( "SkySphere" ) )
    {
       Base::displayObject( o );
    }
