@@ -96,6 +96,8 @@ public:
    virtual void controlPoints( PMControlPointList& list );
    /** */
    virtual void controlPointsChanged( PMControlPointList& list );
+   /** */
+   virtual bool hasDisplayDetail( ) const { return true; }
 
    /**
     * Sets the number of latitutes
@@ -124,14 +126,22 @@ protected:
    /** */
    virtual PMViewStructure* defaultViewStructure( ) const;
    /** */
-   virtual int viewStructureParameterKey( ) const { return s_parameterKey; }
+   virtual int viewStructureParameterKey( ) const { return s_parameterKey + globalDetailKey(); }
 
 private:
+   /**
+    * Creates the faces for the view structure
+    */
+   static void createFaces( PMFaceArray& faces, int uStep, int vStep );
+   /**
+    * Creates the lines for the view structure
+    */
+   static void createLines( PMLineArray& lines, int uStep, int vStep );
    /**
     * Creates the points for the view structure
     */
    static void createPoints( PMPointArray& points, const PMVector& centre,
-                             double radius );
+                             double radius, int uStep, int vStep );
 
    enum PMSphereMementoID { PMRadiusID, PMCentreID };
    /**
