@@ -27,6 +27,7 @@
 #include "pmsolidobject.h"
 #include "pmvector.h"
 #include "pmpoint.h"
+#include "pmline.h"
 
 class PMViewStructure;
 
@@ -92,6 +93,8 @@ public:
 
    /** */
    virtual void restoreMemento( PMMemento* s );
+   /** */
+   virtual bool hasDisplayDetail( ) const { return true; }
 
    /**
     * Sets the number of latitutes
@@ -120,13 +123,17 @@ protected:
    /** */
    virtual PMViewStructure* defaultViewStructure( ) const;
    /** */
-   virtual int viewStructureParameterKey( ) const { return s_parameterKey; }
+   virtual int viewStructureParameterKey( ) const { return s_parameterKey + globalDetailKey( ); }
 
 private:
+   /**
+    * Creates the lines for the view structure
+    */
+   static void createLines( PMLineArray& lines, int uStep, int vStep );
    /**
     * Creates the points for the view structure
     */
-   static void createPoints( PMPointArray& points, double e, double n );
+   static void createPoints( PMPointArray& points, double e, double n, int uStep, int vStep );
 
    /**
     * IDs for @ref PMMementoData
