@@ -36,33 +36,46 @@ PMTriangleEdit::PMTriangleEdit( QWidget* parent, const char* name )
 void PMTriangleEdit::createTopWidgets( )
 {
    Base::createTopWidgets( );
-   
+
    int i;
 
+   QHBoxLayout *hl = new QHBoxLayout( topLayout( ) );
    m_pSmooth = new QCheckBox( i18n( "Smooth" ), this );
-   topLayout( )->addWidget( m_pSmooth );
+   hl->addWidget( m_pSmooth );
    connect( m_pSmooth, SIGNAL( toggled( bool ) ),
             SLOT( slotSmoothChecked( bool ) ) );
 
-   QGridLayout* gl = new QGridLayout( topLayout( ), 6, 2 );
-   
+   m_pUVEnabled = new QCheckBox( i18n( "UV vectors" ), this );
+   hl->addWidget( m_pUVEnabled );
+   connect( m_pUVEnabled, SIGNAL( toggled( bool ) ),
+            SLOT( slotUVVectorsChecked( bool ) ) );
+
+   QGridLayout* gl = new QGridLayout( topLayout( ), 9, 2 );
+
    for( i = 0; i < 3; i++ )
    {
       m_pPoint[i] = new PMVectorEdit( "x", "y", "z", this );
       gl->addWidget( new QLabel( i18n( "Point %1:" ).arg( i+1 ), this ),
-                     i * 2, 0 );
-      gl->addWidget( m_pPoint[i], i * 2, 1 );
+                     i * 3, 0 );
+      gl->addWidget( m_pPoint[i], i * 3, 1 );
       connect( m_pPoint[i], SIGNAL( dataChanged( ) ),
                SIGNAL( dataChanged( ) ) );
 
       m_pNormal[i] = new PMVectorEdit( "x", "y", "z", this );
       m_pNormalLabel[i] = new QLabel( i18n( "Normal %1:" ).arg( i+1 ), this );
-      gl->addWidget( m_pNormalLabel[i], i * 2 + 1, 0 );
-      gl->addWidget( m_pNormal[i], i * 2 + 1, 1 );
+      gl->addWidget( m_pNormalLabel[i], i * 3 + 1, 0 );
+      gl->addWidget( m_pNormal[i], i * 3 + 1, 1 );
       connect( m_pNormal[i], SIGNAL( dataChanged( ) ),
                SIGNAL( dataChanged( ) ) );
+
+      m_pUVVector[i] = new PMVectorEdit( "u", "v", this );
+      m_pUVVectorLabel[i] = new QLabel( i18n( "UV vector %1:" ).arg( i+1 ), this );
+      gl->addWidget( m_pUVVectorLabel[i], i * 3 + 2,  0 );
+      gl->addWidget( m_pUVVector[i], i * 3 + 2, 1 );
+      connect( m_pUVVector[i], SIGNAL( dataChanged( ) ),
+               SIGNAL( dataChanged( ) ) );
    }
-   QHBoxLayout* hl = new QHBoxLayout( topLayout( ) );
+   hl = new QHBoxLayout( topLayout( ) );
    m_pMirror = new QPushButton( i18n( "Invert Normal Vectors" ), this );
    hl->addWidget( m_pMirror );
    hl->addStretch( 1 );
@@ -76,6 +89,7 @@ void PMTriangleEdit::displayObject( PMObject* o )
       bool readOnly = o->isReadOnly( );
       m_pDisplayedObject = ( PMTriangle* ) o;
       bool smooth = m_pDisplayedObject->isSmoothTriangle( );
+      bool uvVector = m_pDisplayedObject->isUVEnabled( );
       int i;
 
       for( i = 0; i < 3; i++ )
@@ -86,6 +100,9 @@ void PMTriangleEdit::displayObject( PMObject* o )
          m_pNormal[i]->setVector( m_pDisplayedObject->normal( i ) );
          m_pNormal[i]->setReadOnly( readOnly );
 
+         m_pUVVector[i]->setVector( m_pDisplayedObject->uvVector( i ) );
+         m_pUVVector[i]->setReadOnly( readOnly );
+
          m_pSmooth->setChecked( smooth );
          if( smooth )
          {
@@ -99,8 +116,22 @@ void PMTriangleEdit::displayObject( PMObject* o )
             m_pNormalLabel[i]->hide( );
             m_pMirror->hide( );
          }
+
+         m_pUVEnabled->setChecked( uvVector );
+         if( uvVector )
+         {
+            m_pUVVector[i]->show( );
+            m_pUVVectorLabel[i]->show( );
+         }
+         else
+         {
+            m_pUVVector[i]->hide( );
+            m_pUVVectorLabel[i]->hide( );
+         }
+
+         emit sizeChanged( );
       }
-      
+
       Base::displayObject( o );
    }
    else
@@ -125,6 +156,27 @@ void PMTriangleEdit::slotSmoothChecked( bool on )
          m_pMirror->hide( );
       }
    }
+   emit sizeChanged( );
+   emit dataChanged( );
+}
+
+void PMTriangleEdit::slotUVVectorsChecked( bool on )
+{
+   int i;
+   for( i = 0; i < 3; ++i )
+   {
+      if( on )
+      {
+         m_pUVVector[i]->show( );
+         m_pUVVectorLabel[i]->show( );
+      }
+      else
+      {
+         m_pUVVector[i]->hide( );
+         m_pUVVectorLabel[i]->hide( );
+      }
+   }
+   emit sizeChanged( );
    emit dataChanged( );
 }
 
@@ -134,7 +186,7 @@ void PMTriangleEdit::slotInvertNormals( )
    for( i = 0; i < 3; i++ )
       if( !m_pNormal[i]->isDataValid( ) )
          return;
-   
+
    for( i = 0; i < 3; i++ )
       m_pNormal[i]->setVector( -( m_pNormal[i]->vector( ) ) );
 }
@@ -147,6 +199,7 @@ void PMTriangleEdit::saveContents( )
       Base::saveContents( );
       for( i = 0; i < 3; i++ )
          m_pDisplayedObject->setPoint( i, m_pPoint[i]->vector( ) );
+
       if( m_pSmooth->isChecked( ) )
       {
          m_pDisplayedObject->setSmoothTriangle( true );
@@ -155,6 +208,15 @@ void PMTriangleEdit::saveContents( )
       }
       else
          m_pDisplayedObject->setSmoothTriangle( false );
+
+      if( m_pUVEnabled->isChecked( ) )
+      {
+         m_pDisplayedObject->enableUV( true );
+         for( i = 0; i < 3; ++i )
+            m_pDisplayedObject->setUVVector( i, m_pUVVector[i]->vector( ) );
+      }
+      else
+         m_pDisplayedObject->enableUV( false );
    }
 }
 
@@ -164,11 +226,11 @@ bool PMTriangleEdit::isDataValid( )
    for( i = 0; i < 3; i++ )
       if( !m_pPoint[i]->isDataValid( ) )
          return false;
-   
+
    PMVector p0 = m_pPoint[0]->vector( ),
             p1 = m_pPoint[1]->vector( ),
             p2 = m_pPoint[2]->vector( );
-   
+
    if( p0.approxEqual( p1 ) || p1.approxEqual( p2 ) || p0.approxEqual( p2 ) )
    {
       KMessageBox::error( this, i18n( "Please enter a valid triangle." ),
@@ -198,6 +260,12 @@ bool PMTriangleEdit::isDataValid( )
       }
    }
 
+   if( m_pUVEnabled->isChecked( ) )
+   {
+      for( i = 0; i < 3; ++i )
+         if( !m_pUVVector[i]->isDataValid( ) )
+            return false;
+   }
 
    return Base::isDataValid( );
 }
