@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -533,6 +533,7 @@ SVGElementImpl *SVGDocumentImpl::recursiveSearch(DOM::Node start, const DOM::DOM
 }
 
 /*
+@namespace KSVG
 @begin	SVGDocumentImpl::s_hashTable 9
  title				SVGDocumentImpl::Title				DontDelete|ReadOnly
  referrer			SVGDocumentImpl::Referrer			DontDelete|ReadOnly
@@ -543,6 +544,7 @@ SVGElementImpl *SVGDocumentImpl::recursiveSearch(DOM::Node start, const DOM::DOM
  rootElement		SVGDocumentImpl::RootElement		DontDelete|ReadOnly
  documentElement	SVGDocumentImpl::DocumentElement	DontDelete|ReadOnly
 @end
+@namespace KSVG
 @begin SVGDocumentImplProto::s_hashTable 7
  createTextNode			SVGDocumentImpl::CreateTextNode			DontDelete|Function 1
  createElement			SVGDocumentImpl::CreateElement			DontDelete|Function 1
