@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     aint with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <math.h>
@@ -128,7 +128,7 @@ std::string Font::buildRequest(const FontVisualParams *fontParams, int &id)
 							 FC_WEIGHT, FcTypeInteger, fontParams->weight(),
 							 FC_SLANT, FcTypeInteger, fontParams->slant(),
 							 FC_SIZE, FcTypeDouble, fontParams->size(),
-							 0);
+							 NULL);
 
 	// Add multiple font names
 	std::list<std::string> &fontList = const_cast<FontVisualParams *>(fontParams)->fontList();
