@@ -421,20 +421,29 @@ void LibartShape::calcSVPInternal(ArtVpath *vec, SVGStylableImpl *style, double
 		unsigned int dashLength;
 		if(style->getDashArray() && (dashLength = style->getDashArray()->baseVal()->numberOfItems()) > 0)
 		{
+			// HACK: libart will hang in art_vpath_dash() if passed an array with only zeroes.
+			bool allZeroes = true;
+
 			// there are dashes to be rendered
 			ArtVpathDash dash;
 			dash.offset = int(style->getDashOffset()->baseVal()->value()) * ratio;
 			dash.n_dash = dashLength;
 			double *dashes = new double[dashLength];
 			for(unsigned int i = 0; i < dashLength; i++)
+			{
 				dashes[i] = style->getDashArray()->baseVal()->getItem(i)->value() * ratio;
+				if(dashes[i] != 0.0)
+					allZeroes = false;
+			}
 			dash.dash = dashes;
 
-			// get the dashed VPath and use that for the stroke render operation
-			ArtVpath *vec2 = art_vpath_dash(vec, &dash);
-			art_free(vec);
-
-			vec = vec2;
+			if(!allZeroes)
+			{
+				// get the dashed VPath and use that for the stroke render operation
+				ArtVpath *vec2 = art_vpath_dash(vec, &dash);
+				art_free(vec);
+				vec = vec2;
+			}
 
 			// reset the dashes
 			delete [] dashes;
