@@ -6,7 +6,7 @@
 
 static KCmdLineOptions options[] =
 {
-	{ "+URL",   I18N_NOOP("SVG file to open."), 0 },
+	{ "+URL",   I18N_NOOP("SVG file to open"), 0 },
 	KCmdLineLastOption
 };
 
