@@ -66,9 +66,6 @@ class KDE_EXPORT KViewViewer : public KImageViewer::Viewer, public KViewViewerIf
 		virtual void newImage( const QImage & );
 		virtual void reload();
 
-	signals:
-		void imageOpened( const KURL & );
-
 	protected:
 		bool eventFilter( QObject *, QEvent * ); // for DnD
 		void abortLoad();
