@@ -2,11 +2,13 @@
 //
 // Part of KVIEWSHELL - A framework for multipage text/gfx viewers
 //
-// (C) 2002 Stefan Kebekus
+// (C) 2002-2003 Stefan Kebekus
 // Distributed under the GPL
 
 // Add header files alphabetically
 
+#include <config.h>
+
 #include <kapplication.h>
 #include <kcombobox.h>
 #include <klocale.h>
@@ -17,14 +19,17 @@
 #include <qvalidator.h>
 #include <qhbox.h>
 
+
+
 #include "pageSizeDialog.h"
 #include "pageSizeWidget.h"
 
 
-pageSizeDialog::pageSizeDialog( QWidget *parent, const char *name, bool modal)
+pageSizeDialog::pageSizeDialog( QWidget *parent, pageSize *userPrefdPageSize, const char *name, bool modal)
   :KDialogBase( parent, name, modal, i18n("Page Size"), Ok|Apply|Cancel, Ok, 
 		true )
 {
+  userPreferredPageSize = userPrefdPageSize;
   pageSizeW = new pageSizeWidget(this, "PageSizeWidget");
   pageSizeW->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)3, 0, 0, 
 					 pageSizeW->sizePolicy().hasHeightForWidth() ) );
@@ -34,28 +39,25 @@ pageSizeDialog::pageSizeDialog( QWidget *parent, const char *name, bool modal)
 
 void pageSizeDialog::slotOk()
 {
-  emit(sizeSelected(pageSizeW->serialize(), pageSizeW->orientationChoice->currentItem()));
+  if (userPreferredPageSize != 0)
+    *userPreferredPageSize = pageSizeW->pageSizeData();
   accept();
 }
 
 
 void pageSizeDialog::slotApply()
 {
-  emit(sizeSelected(pageSizeW->serialize(), pageSizeW->orientationChoice->currentItem()));
+  if (userPreferredPageSize != 0)
+    *userPreferredPageSize = pageSizeW->pageSizeData();
 }
 
 
-void pageSizeDialog::setPageSize(QString name)
+void pageSizeDialog::setPageSize(const QString& name)
 {
   if (pageSizeW == 0)
     return;
   pageSizeW->setPageSize(name);
 }
 
-void pageSizeDialog::setOrientation(int ori)
-{
-  if (pageSizeW != 0)
-    pageSizeW->setOrientation(ori);
-}
 
 #include "pageSizeDialog.moc"
