@@ -6,18 +6,21 @@
 // (C) 2001--2004 Stefan Kebekus
 // Distributed under the GPL
 
+#include <config.h>
+
 #include <qapplication.h>
 #include <qclipboard.h>
 
 #include "selection.h"
 
+TextSelection::TextSelection()
+  : page(PageNumber::invalidPage),
+    selectedText(QString::null)
+{}
 
 
-void textSelection::set(PageNumber pageNr, Q_INT32 start, Q_INT32 end, const QString &text)
+void TextSelection::set(const PageNumber& pageNr, Q_INT32 start, Q_INT32 end, const QString& text)
 {
-  Q_UINT16 oldpage    = page;
-  bool     oldIsEmpty = isEmpty();
-  
   page              = pageNr;
   selectedTextStart = start;
   selectedTextEnd   = end;
@@ -25,22 +28,29 @@ void textSelection::set(PageNumber pageNr, Q_INT32 start, Q_INT32 end, const QSt
     selectedText = text;
   else
     selectedText = QString::null;
-  
+
   if (page != 0) {
     QApplication::clipboard()->setSelectionMode(true);
     QApplication::clipboard()->setText(selectedText);
   }
-
-  // If the state of the selection has changed, emit the appropriate
-  // signals
-  if (isEmpty() != oldIsEmpty)
-    emit selectionIsNotEmpty( !isEmpty() );
-  if (page != oldpage)
-    emit pageChanged();
 }
 
 
-void textSelection::copyText(void) const
+bool TextSelection::operator== (const TextSelection& s) const
+{
+  // We don't check if the strings are equal because for corretly constructed selection objects this is always
+  // the case if the following condition holds.
+  return (page == s.page && selectedTextStart == s.selectedTextStart && selectedTextEnd == s.selectedTextEnd);
+}
+
+
+bool TextSelection::operator!= (const TextSelection& s) const
+{
+  return !(*this == s);
+}
+
+
+void TextSelection::copyText() const
 {
   if (!isEmpty()) {
     QApplication::clipboard()->setSelectionMode(false);
@@ -49,10 +59,8 @@ void textSelection::copyText(void) const
 }
 
 
-void textSelection::clear(void)
+void TextSelection::clear()
 {
   set(0, -1, -1, QString::null);
 }
 
-
-#include "selection.moc"
